#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "copt.h"

static void print_usage(char *cmdname) {
  printf("Command line usage:\n");
  printf("    %s [-t timelimit] model.mps[.gz]\n", cmdname);
  printf("\n");
  printf("Example:\n");
  printf("    %s model.mps\n", cmdname);
  printf("    %s -t 7200 model.mps\n", cmdname);
}

int main(int argc, char **argv) {
  copt_env *env = NULL;
  copt_prob *prob = NULL;
  char buff[COPT_BUFFSIZE];
  int ifCmdOK = 0;

  COPT_GetBanner(buff, 1000);
  printf("%s\n", buff);

  int iRet = COPT_CreateEnv(&env);
  if (iRet != 0) {
    COPT_GetLicenseMsg(env, buff, COPT_BUFFSIZE);
    printf("%s\n", buff);
    goto exit_cleanup;
  }

  if (argc == 2) {
    /* Create the LP and read in from the MPS file */
    ifCmdOK = 1;
    COPT_CreateProb(env, &prob);
    COPT_SetDblParam(prob, COPT_DBLPARAM_TIMELIMIT, 3600);

    int retcode = COPT_ReadMps(prob, argv[1]);
    if (retcode != 0) {
      goto exit_cleanup;
    }

    /* Solve the problem */
    COPT_SolveLp(prob);
  } else if (argc == 4) {
    /* Check that the first option is -t and it followed by a number */
    double dTimeLim = 0;
    if (strcmp(argv[1], "-t") == 0) {
      char *ptr = NULL;
      dTimeLim = strtod(argv[2], &ptr);
      if (ptr != argv[2] && dTimeLim > 0.0) {
        ifCmdOK = 1;
      }
    }

    if (ifCmdOK) {
      /* Create the problem and set the time limt */
      COPT_CreateProb(env, &prob);
      COPT_SetDblParam(prob, COPT_DBLPARAM_TIMELIMIT, dTimeLim);

      /* Read the problem */
      int retcode = COPT_ReadMps(prob, argv[3]);
      if (retcode != 0) {
        goto exit_cleanup;
      }

      /* Solve the problem */
      COPT_SolveLp(prob);
    }
  }

  if (ifCmdOK == 0) {
    print_usage(argv[0]);
  }

  exit_cleanup:
  COPT_DeleteProb(&prob);
  COPT_DeleteEnv(&env);
  return 0;
}

